#
# spec file for package libgepub
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define basever 0.7
%define soname 0_7
%global sover   0

Name:           libgepub
Version:        0.7.1
Release:        1.5
Summary:        EPUB document reader and render library
License:        LGPL-2.1-or-later
Group:          Development/Languages/C and C++
URL:            https://gitlab.gnome.org/GNOME/libgepub
Source0:        https://download.gnome.org/sources/%{name}/%{basever}/%{name}-%{version}.tar.xz

BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.30.0
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(webkit2gtk-4.1)

%description
A GObject-based library for handling and rendering EPUB documents.

%package -n %{name}-%{soname}-%{sover}
Summary:        EPUB document reader library
Group:          System/Libraries

%description -n %{name}-%{soname}-%{sover}
A GObject-based library for handling and rendering EPUB documents.

%package -n typelib-1_0-Gepub-%{soname}
Summary:        Introspection bindings for libgepub
Group:          System/Libraries

%description -n typelib-1_0-Gepub-%{soname}
A GObject-based library for handling and rendering EPUB documents.

%package devel
Summary:        Development files for libgepub
Group:          Development/Languages/C and C++
Requires:       %{name}-%{soname}-%{sover} = %{version}
Requires:       typelib-1_0-Gepub-%{soname} = %{version}

%description devel
A GObject-based library for handling and rendering EPUB documents.

%prep
%autosetup

%build
%meson \
	-D introspection=true \
	%{nil}
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n %{name}-%{soname}-%{sover}

%files -n %{name}-%{soname}-%{sover}
%license COPYING
%{_libdir}/%{name}-%{basever}.so.*

%files -n typelib-1_0-Gepub-%{soname}
%{_libdir}/girepository-1.0/Gepub-%{basever}.typelib

%files devel
%doc AUTHORS MAINTAINERS NEWS README
%{_includedir}/%{name}-%{basever}/
%{_libdir}/%{name}-%{basever}.so
%{_libdir}/pkgconfig/%{name}-%{basever}.pc
%{_datadir}/gir-1.0/Gepub-%{basever}.gir

%changelog
* Wed Jun 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.7.1:
  + doc: Fix Crash in gepub_doc_new().
* Thu Sep  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.7.0:
  + Make gepub-widget configurable with "-Dwidget=false"
  + Use libsoup 3.0
  + Fix memory leak
  + Remove absolute external resources from gepub
  + widget
  - Disable a number of "Web" features
  - Fix ePubs not rendering after the first one
  + Stop chapter number updates breaking navigation to anchor links
  + Update the chapter number when the page changes
  + Work with file paths, not URI substrings, in custom URI scheme
  + Do not rewrite page-relative anchor links
  + Use new JavaScriptCore GLib API instead of DOM API
  + Use compiler.has_link_argument() for linker flags
  + Unscape paths before get from the archive
  + Add TOC parse to GepubDoc
- Replace pkgconfig(libsoup-2.4) and pkgconfig(webkit2gtk-4.0) with
  pkgconfig(libsoup-3.0) and pkgconfig(webkit2gtk-4.1)
  BuildRequires following uptream changes.
- Bump soname following upstreams bump in soname.
- Use ldconfig_scriptlets macro for post(un) handling.
* Thu Mar 15 2018 bjorn.lie@gmail.com
- Update to version 0.6.0:
  + Support setting font-family in GepubWidget.
  + Fix the gir generation.
  + widget: Fix warning at run-time.
  + lib: Fix gepub-widget chapter change signal.
- Bump basever to 0.6 and soname to 0_6 following upstream changes.
- Rename libgepub0 subpackage following upstream changes to
  libgepub-0_6-0, make needed changes in post(un) handling due to
  namechange.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Jan 19 2018 bjorn.lie@gmail.com
- Update to version 0.5.3:
  + Fixed SVG image resource replacement.
  + Rename introspection build option.
  + Removed autotools.
  + build:
  - Conform to build-api expectations.
  - Remove default warning level.
  - Remove unused defines.
  - Improved linker script handling.
  - Set prefix-relative install_dir for libgepub.
  - Fix typo in symbol path creation.
  + tests:
  - Fix crash on exit.
  - Replace "100" with a constant.
  - widget: Don't change LC_NUMERIC at runtime.
- Pass introspection=true to meson, ensure we build the features
  we want.
- Minor spec cleanup, use autosetup macro.
* Fri Sep  8 2017 jengelh@inai.de
- Update descriptions.
* Wed Aug  9 2017 zaitor@opensuse.org
- Update to version 0.5.2:
  + Fixed gir version.
- Changes from version 0.5.1:
  + Added GError to gepub_doc_new new method.
  + Fixed meson build scripts.
- Add a baserver define and set it to 0.5
* Wed Jul 12 2017 zaitor@opensuse.org
- Update to version 0.5:
  + Fixed page next and page prev signals.
  + Added file property to support GFile initialization.
  + Fixed some memory leaks.
  + Removed all compilation warnings.
  + Added pagination to the GepubWidget.
  + Added Simple text style modification in the widget.
  + Ported to meson build system.
  + Fixed epub:// SoupURI creation and concatenation.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Drop gnome-common BuildRequires, no longer needed.
- Switch to using released tarball, remove use of _service.
- Rename typelib-1_0-Gepub-0_4 to typelib-1_0-Gepub-0_5 following
  upstream changes.
- Add soname define and set it to 0_5, ease future updates.
* Wed Aug 31 2016 dimstar@opensuse.org
- Update to version 0.4:
  + go_next and go_prev returns TRUE if success.
  + Added functions to get the current doc mime and path.
  + Fixed resource path for relative and doc paths.
  + Remove libarchive from the public API.
  + Simplify pkg-config file.
  + Don't link the library against GTK+.
  + Function to replace relative resources by epub://.
  + utils: replace epub:// URIs for crosslinks too.
  + utils: correctly terminate base URI.
  + doc: fix wrong path when looking for resources.
  + doc: make API to get resources consistent.
  + Added GepubWidget class to show the content with webkit.
  + Don't NULL-terminate document content.
  + utils: remove unused variable.
  + build: highlight introspection warnings.
  + build: fix introspection warnings.
  + Fixes in gepub-widget to work with the last merge.
  + widget: make it a WebKitWebView.
  + widget: simplify code.
  + Fix gtk-doc annotations.
  + widget: make the GepubDoc a property.
  + doc: remove unneeded API.
  + doc: use htmlReadMemory().
  + widget: plug a memory leak.
  + Rework API to be based on GBytes.
  + doc: trivial indentation fix.
  + Const-ify API methods that take strings.
  + doc: don't call g_list_append().
  + doc: rework page API.
  + widget: automatically reload chapter when current page changes.
  + Ignore HTML entities parse error when loading xml.
  + New release 0.4.
- Add pkgconfig(libsoup-2.4) and pkgconfig(webkit2gtk-4.0)
  BuildRequires: new dependencies.
- Rename typelib-1_0-Gepub-0_3 subpackage to typelib-1_0-Gepub-0_4,
  following upstreams rename of the typelib file.
* Tue Aug 23 2016 dimstar@opensuse.org
- Initial package, version 0.3.
